//+------------------------------------------------------------------+
//|                                        Turtle Channel Method.mq4 |
//|                      Copyright  2008, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"
// - Original Donchain channel code posted here: http://codebase.mql4.com/ru/1317


#property indicator_chart_window
//---- input parameters
#property indicator_buffers 6
#property indicator_color1 White
#property indicator_color2 White
#property indicator_color3 Yellow
#property indicator_color4 Yellow
#property indicator_color5 Red
#property indicator_color6 Red

//Periods: number of bars used for calculating the Donchian channel 
//Extremes: 1 uses the highest high and the lowest low to create the Channel
//          0 uses the open of the extremes bar -> the open point of a bar (as well as the close
//				   are the points of maximum probability of concentration of the prices during the bar
//          3 uses the median point most extreme open and lowest low or highest high
//Margins: is the percent of the channel subtrated from the channel border before printing it, negative values are allowed
//Advance: the numbers of bars ahead

// - Input Periods - 
extern int  LngPeriod=50;
extern int  MdPeriod=20;
extern int  ShtPeriod=10;
extern int  Extremes=1;
extern int  Margins=0;
extern int  Advance=0;
extern int  max_bars=1400;

// - Buffers
double Channel1[];
double Channel2[];
double Channel3[];
double Channel4[];
double Channel5[];
double Channel6[];


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
  //Comment("Turtle Channels is running");
  string LngTop, LngBottom, MedTop, MedBottom, ShtTop, ShtBottom;
  
//---- indicators
   SetIndexStyle(0,DRAW_LINE,2,0);
   SetIndexStyle(1,DRAW_LINE,2,0);
   SetIndexStyle(2,DRAW_LINE,1,0);
   SetIndexStyle(3,DRAW_LINE,1,0);
   SetIndexStyle(4,DRAW_LINE,3,0);
   SetIndexStyle(5,DRAW_LINE,3,0);
   
   SetIndexBuffer(0,Channel1);
   SetIndexBuffer(1,Channel2);
   SetIndexBuffer(2,Channel3);
   SetIndexBuffer(3,Channel4);
   SetIndexBuffer(4,Channel5);
   SetIndexBuffer(5,Channel6);
   
   LngTop = "Long Top";
   LngBottom = "Long Bottom";
   MedTop = "Medium Top";
   MedBottom = "Medium Bottom";
   ShtTop = "Short Top";
   ShtBottom = "Short Bottom";
   
   IndicatorShortName(LngTop);
   IndicatorShortName(LngBottom);
   IndicatorShortName(MedTop);
   IndicatorShortName(MedBottom);
   IndicatorShortName(ShtTop);
   IndicatorShortName(ShtBottom);
   
   SetIndexLabel(0,LngTop);
   SetIndexLabel(1,LngBottom);
   SetIndexLabel(2,MedTop);
   SetIndexLabel(3,MedBottom);
   SetIndexLabel(4,ShtTop);
   SetIndexLabel(5,ShtBottom);
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int   fixed_Bars=IndicatorCounted();

   double   sminl=0, smaxl=0, SsMinl=0, SsMaxl=0;
   double   sminm=0, smaxm=0, SsMinm=0, SsMaxm=0;
   double   smins=0, smaxs=0, SsMins=0, SsMaxs=0;

//----
   for(int shift=0;shift< max_bars; shift++)
   
   {
	  if (Extremes ==1)
	  {
	     SsMaxl = High[Highest(NULL,0,MODE_HIGH,LngPeriod,shift)];
	     SsMinl = Low[Lowest(NULL,0,MODE_LOW,LngPeriod,shift)];
	     SsMaxm = High[Highest(NULL,0,MODE_HIGH,MdPeriod,shift)];
	     SsMinm = Low[Lowest(NULL,0,MODE_LOW,MdPeriod,shift)];
	     SsMaxs = High[Highest(NULL,0,MODE_HIGH,ShtPeriod,shift)];
	     SsMins = Low[Lowest(NULL,0,MODE_LOW,ShtPeriod,shift)];
	  }
	  else if (Extremes == 3)
	  {
	     SsMaxl = (Open[Highest(NULL,0,MODE_OPEN,LngPeriod,shift)]+High[Highest(NULL,0,MODE_HIGH,LngPeriod,shift)])/2;
	     SsMinl = (Open[Lowest(NULL,0,MODE_OPEN,LngPeriod,shift)]+Low[Lowest(NULL,0,MODE_LOW,LngPeriod,shift)])/2;
	     SsMaxm = (Open[Highest(NULL,0,MODE_OPEN,MdPeriod,shift)]+High[Highest(NULL,0,MODE_HIGH,MdPeriod,shift)])/2;
	     SsMinm = (Open[Lowest(NULL,0,MODE_OPEN,MdPeriod,shift)]+Low[Lowest(NULL,0,MODE_LOW,MdPeriod,shift)])/2;
	     SsMaxs = (Open[Highest(NULL,0,MODE_OPEN,ShtPeriod,shift)]+High[Highest(NULL,0,MODE_HIGH,ShtPeriod,shift)])/2;
	     SsMins = (Open[Lowest(NULL,0,MODE_OPEN,ShtPeriod,shift)]+Low[Lowest(NULL,0,MODE_LOW,ShtPeriod,shift)])/2;
	  }
	     else
	  {
	     SsMaxl = Open[Highest(NULL,0,MODE_OPEN,LngPeriod,shift)];
		  SsMinl = Open[Lowest(NULL,0,MODE_OPEN,LngPeriod,shift)];
   	  SsMaxm = Open[Highest(NULL,0,MODE_OPEN,MdPeriod,shift)];
		  SsMinm = Open[Lowest(NULL,0,MODE_OPEN,MdPeriod,shift)];
		  SsMaxs = Open[Highest(NULL,0,MODE_OPEN,ShtPeriod,shift)];
		  SsMins = Open[Lowest(NULL,0,MODE_OPEN,ShtPeriod,shift)];
	  }
	  
	  smaxl = SsMaxl-(SsMaxl-SsMinl)*Margins/100;
	  sminl = SsMinl+(SsMaxl-SsMinl)*Margins/100;
	  smaxm = SsMaxm-(SsMaxm-SsMinm)*Margins/100;
	  sminm = SsMinm+(SsMaxm-SsMinm)*Margins/100;
	  smaxs = SsMaxs-(SsMaxs-SsMins)*Margins/100;
	  smins = SsMins+(SsMaxs-SsMins)*Margins/100;
	  
	  Channel1[shift-Advance]=smaxl;
	  Channel2[shift-Advance]=sminl;
	  Channel3[shift-Advance]=smaxm;
	  Channel4[shift-Advance]=sminm;
	  Channel5[shift-Advance]=smaxs;
	  Channel6[shift-Advance]=smins;
	}
      
   
//----
   return(0);
  }
//+------------------------------------------------------------------+